"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Section = void 0;
var classnames_1 = __importDefault(require("classnames"));
var react_1 = __importDefault(require("react"));
var styles_module_css_json_1 = __importDefault(require("./styles.module.css.json"));
/**
 * @example Basic usage
 *
 * ```jsx
 * <Canvas ctx={ctx}>
 *   <Section title="Section title">
 *     Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
 *     eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim
 *     ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut
 *     aliquip ex ea commodo consequat.
 *   </Section>
 * </Canvas>;
 * ```
 *
 * @example Highlighted
 *
 * ```jsx
 * <Canvas ctx={ctx}>
 *   <Section title="Section title" highlighted>
 *     Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
 *     eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim
 *     ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut
 *     aliquip ex ea commodo consequat.
 *   </Section>
 * </Canvas>;
 * ```
 *
 * @example Collapsible
 *
 * ```jsx
 * <Canvas ctx={ctx}>
 *   <StateManager initial={true}>
 *     {(isOpen, setOpen) => (
 *       <Section
 *         title="Section title"
 *         collapsible={{ isOpen, onToggle: () => setOpen((v) => !v) }}
 *       >
 *         Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
 *         eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut
 *         enim ad minim veniam, quis nostrud exercitation ullamco laboris
 *         nisi ut aliquip ex ea commodo consequat.
 *       </Section>
 *     )}
 *   </StateManager>
 * </Canvas>;
 * ```
 */
function Section(_a) {
    var _b, _c;
    var title = _a.title, children = _a.children, highlighted = _a.highlighted, collapsible = _a.collapsible, headerClassName = _a.headerClassName, titleClassName = _a.titleClassName, headerStyle = _a.headerStyle, titleStyle = _a.titleStyle;
    return (react_1.default.createElement("div", { className: (0, classnames_1.default)(styles_module_css_json_1.default.Section, (_b = {}, _b[styles_module_css_json_1.default['Section--highlighted']] = highlighted, _b)) },
        react_1.default.createElement("div", { className: (0, classnames_1.default)(styles_module_css_json_1.default.Section__header, headerClassName), style: headerStyle },
            react_1.default.createElement("div", { className: (0, classnames_1.default)(styles_module_css_json_1.default.Section__title, titleClassName), style: titleStyle },
                collapsible && (react_1.default.createElement("button", { type: "button", className: (0, classnames_1.default)(styles_module_css_json_1.default.Section__arrow, (_c = {},
                        _c[styles_module_css_json_1.default['Section__arrow--is-open']] = collapsible.isOpen,
                        _c)), onClick: collapsible.onToggle })),
                react_1.default.createElement("div", { className: styles_module_css_json_1.default.Section__title__content }, title))),
        (!collapsible || collapsible.isOpen) && children));
}
exports.Section = Section;
//# sourceMappingURL=index.js.map