"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Toolbar = void 0;
var classnames_1 = __importDefault(require("classnames"));
var react_1 = __importDefault(require("react"));
var styles_module_css_json_1 = __importDefault(require("./styles.module.css.json"));
/**
 * - @example Basic example
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <Toolbar>
 *     <ToolbarStack stackSize="l">
 *       <ToolbarTitle>Media Area</ToolbarTitle>
 *     </ToolbarStack>
 *   </Toolbar>
 *   <div
 *     style={{
 *       display: 'flex',
 *       justifyContent: 'center',
 *       alignItems: 'center',
 *       background: 'var(--light-bg-color)',
 *       height: '150px',
 *     }}
 *   >
 *     Main content
 *   </div>
 * </Canvas>;
 * ```
 *
 * @example Buttons and actions
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <Toolbar>
 *     <ToolbarButton>
 *       <BackIcon />
 *     </ToolbarButton>
 *     <ToolbarStack stackSize="l">
 *       <ToolbarTitle>Media Area</ToolbarTitle>
 *       <div style={{ flex: '1' }} />
 *       <Button buttonType="primary">Action</Button>
 *     </ToolbarStack>
 *     <ToolbarButton>
 *       <SidebarLeftArrowIcon />
 *     </ToolbarButton>
 *   </Toolbar>
 *   <div
 *     style={{
 *       display: 'flex',
 *       justifyContent: 'center',
 *       alignItems: 'center',
 *       background: 'var(--light-bg-color)',
 *       height: '150px',
 *     }}
 *   >
 *     Main content
 *   </div>
 * </Canvas>;
 * ```
 *
 * @example With button group
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <Toolbar>
 *     <ToolbarStack stackSize="l">
 *       <ToolbarTitle>Media Area</ToolbarTitle>
 *       <div style={{ flex: '1' }} />
 *       <ButtonGroup>
 *         <ButtonGroupButton>First</ButtonGroupButton>
 *         <ButtonGroupButton selected>Second</ButtonGroupButton>
 *         <ButtonGroupButton>Third</ButtonGroupButton>
 *       </ButtonGroup>
 *     </ToolbarStack>
 *   </Toolbar>
 *   <div
 *     style={{
 *       display: 'flex',
 *       justifyContent: 'center',
 *       alignItems: 'center',
 *       background: 'var(--light-bg-color)',
 *       height: '150px',
 *     }}
 *   >
 *     Main content
 *   </div>
 * </Canvas>;
 * ```
 */
function Toolbar(_a) {
    var children = _a.children, style = _a.style, className = _a.className;
    return (react_1.default.createElement("div", { className: (0, classnames_1.default)(styles_module_css_json_1.default.Toolbar, className), style: style }, children));
}
exports.Toolbar = Toolbar;
//# sourceMappingURL=index.js.map