"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.VerticalSplit = void 0;
var classnames_1 = __importDefault(require("classnames"));
var react_1 = __importStar(require("react"));
var SplitView_1 = require("../SplitView");
var SplitViewPane_1 = require("../SplitView/SplitViewPane");
var styles_module_css_json_1 = __importDefault(require("../SplitView/SplitViewSash/styles.module.css.json"));
var icons_1 = require("../icons");
var styles_module_css_json_2 = __importDefault(require("./styles.module.css.json"));
var initialSidebarWidth = 220;
function calculateSizes(_a) {
    var size = _a.size, primaryPane = _a.primaryPane, isSecondaryCollapsed = _a.isSecondaryCollapsed;
    var realSize = isSecondaryCollapsed ? 20 : size;
    return primaryPane === 'right' ? [realSize] : ['auto', realSize];
}
/**
 * @example Resizable, left primary panel
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <div style={{ height: 500, position: 'relative' }}>
 *     <VerticalSplit primaryPane="left" size="25%" minSize={220}>
 *       <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
 *         <Toolbar>
 *           <ToolbarStack stackSize="l">
 *             <ToolbarTitle>Primary</ToolbarTitle>
 *           </ToolbarStack>
 *         </Toolbar>
 *         <div
 *           style={{
 *             flex: '1',
 *             display: 'flex',
 *             justifyContent: 'center',
 *             alignItems: 'center',
 *             height: '150px',
 *           }}
 *         >
 *           Main content
 *         </div>
 *       </div>
 *       <div style={{ display: 'flex', flexDirection: 'column', height: '100%', borderLeft: '1px solid var(--border-color)' }}>
 *         <Toolbar>
 *           <ToolbarStack stackSize="l">
 *             <ToolbarTitle>Secondary</ToolbarTitle>
 *           </ToolbarStack>
 *         </Toolbar>
 *         <div
 *           style={{
 *             flex: '1',
 *             display: 'flex',
 *             justifyContent: 'center',
 *             alignItems: 'center',
 *             height: '150px',
 *           }}
 *         >
 *           Sidebar
 *         </div>
 *       </div>
 *     </VerticalSplit>
 *   </div>
 * </Canvas>;
 * ```
 *
 * @example Resizable, right primary panel
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <div style={{ height: 500, position: 'relative' }}>
 *     <VerticalSplit primaryPane="right" size="25%" minSize={220}>
 *       <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
 *         <Toolbar>
 *           <ToolbarStack stackSize="l">
 *             <ToolbarTitle>Secondary</ToolbarTitle>
 *           </ToolbarStack>
 *         </Toolbar>
 *         <div
 *           style={{
 *             flex: '1',
 *             display: 'flex',
 *             justifyContent: 'center',
 *             alignItems: 'center',
 *             height: '150px',
 *           }}
 *         >
 *           Sidebar
 *         </div>
 *       </div>
 *       <div style={{ display: 'flex', flexDirection: 'column', height: '100%', borderLeft: '1px solid var(--border-color)' }}>
 *         <Toolbar>
 *           <ToolbarStack stackSize="l">
 *             <ToolbarTitle>Primary</ToolbarTitle>
 *           </ToolbarStack>
 *         </Toolbar>
 *         <div
 *           style={{
 *             flex: '1',
 *             display: 'flex',
 *             justifyContent: 'center',
 *             alignItems: 'center',
 *             height: '150px',
 *           }}
 *         >
 *           Main content
 *         </div>
 *       </div>
 *     </VerticalSplit>
 *   </div>
 * </Canvas>;
 * ```
 *
 * @example Collapsible
 *
 * ```js
 *   <Canvas ctx={ctx}>
 *    <div style={{ height: 500, position: 'relative' }}>
 *      <StateManager initial={true}>
 *        {(isCollapsed, setCollapsed) => (
 *          <VerticalSplit
 *            primaryPane="left"
 *            size="25%"
 *            minSize={220}
 *            isSecondaryCollapsed={isCollapsed}
 *            onSecondaryToggle={setCollapsed}
 *          >
 *            <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
 *              <Toolbar>
 *                <ToolbarStack stackSize="l">
 *                  <ToolbarTitle>Primary</ToolbarTitle>
 *                </ToolbarStack>
 *              </Toolbar>
 *              <div
 *                style={{
 *                  flex: '1',
 *                  display: 'flex',
 *                  justifyContent: 'center',
 *                  alignItems: 'center',
 *                  height: '150px',
 *                }}
 *              >
 *                Main content
 *              </div>
 *            </div>
 *            <div
 *              style={{
 *                display: 'flex',
 *                flexDirection: 'column',
 *                height: '100%',
 *                borderLeft: '1px solid var(--border-color)',
 *              }}
 *            >
 *              <Toolbar>
 *                <ToolbarStack stackSize="l">
 *                  <ToolbarTitle>Secondary</ToolbarTitle>
 *                </ToolbarStack>
 *              </Toolbar>
 *              <div
 *                style={{
 *                  flex: '1',
 *                  display: 'flex',
 *                  justifyContent: 'center',
 *                  alignItems: 'center',
 *                  height: '150px',
 *                }}
 *              >
 *                Sidebar
 *              </div>
 *            </div>
 *          </VerticalSplit>
 *        )}
 *      </StateManager>
 *    </div>
 *  </Canvas>;
 * ```
 *
 * @example Overlay mode
 *
 * ```js
 *   <Canvas ctx={ctx}>
 *    <div style={{ height: 500, position: 'relative' }}>
 *      <StateManager initial={true}>
 *        {(isCollapsed, setCollapsed) => (
 *          <VerticalSplit
 *            mode="overlay"
 *            primaryPane="left"
 *            size="25%"
 *            minSize={220}
 *            isSecondaryCollapsed={isCollapsed}
 *            onSecondaryToggle={setCollapsed}
 *          >
 *            <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
 *              <Toolbar>
 *                <ToolbarStack stackSize="l">
 *                  <ToolbarTitle>Primary</ToolbarTitle>
 *                </ToolbarStack>
 *              </Toolbar>
 *              <div
 *                style={{
 *                  flex: '1',
 *                  display: 'flex',
 *                  justifyContent: 'center',
 *                  alignItems: 'center',
 *                  height: '150px',
 *                }}
 *              >
 *                Main content
 *              </div>
 *            </div>
 *            <div
 *              style={{
 *                display: 'flex',
 *                flexDirection: 'column',
 *                height: '100%',
 *                borderLeft: '1px solid var(--border-color)',
 *              }}
 *            >
 *              <Toolbar>
 *                <ToolbarStack stackSize="l">
 *                  <ToolbarTitle>Secondary</ToolbarTitle>
 *                </ToolbarStack>
 *              </Toolbar>
 *              <div
 *                style={{
 *                  flex: '1',
 *                  display: 'flex',
 *                  justifyContent: 'center',
 *                  alignItems: 'center',
 *                  height: '150px',
 *                }}
 *              >
 *                Sidebar
 *              </div>
 *            </div>
 *          </VerticalSplit>
 *        )}
 *      </StateManager>
 *    </div>
 *  </Canvas>;
 * ```
 */
function VerticalSplit(_a) {
    var _b = _a.mode, mode = _b === void 0 ? 'split' : _b, _c = _a.minSize, minSize = _c === void 0 ? 200 : _c, maxSize = _a.maxSize, _d = _a.size, size = _d === void 0 ? initialSidebarWidth : _d, primaryPane = _a.primaryPane, children = _a.children, _e = _a.allowResize, allowResize = _e === void 0 ? true : _e, onDragFinished = _a.onDragFinished, onSecondaryToggle = _a.onSecondaryToggle, isSecondaryCollapsed = _a.isSecondaryCollapsed;
    var _f = (0, react_1.useState)(calculateSizes({ size: size, primaryPane: primaryPane, isSecondaryCollapsed: isSecondaryCollapsed })), sizes = _f[0], setSizes = _f[1];
    var currentSizes = (0, react_1.useRef)(sizes);
    var SashActionIcon = onSecondaryToggle
        ? primaryPane === 'left'
            ? isSecondaryCollapsed
                ? icons_1.SidebarFlipIcon
                : icons_1.ChevronsRightIcon
            : isSecondaryCollapsed
                ? icons_1.ChevronsRightIcon
                : icons_1.ChevronsLeftIcon
        : undefined;
    (0, react_1.useEffect)(function () {
        setSizes(calculateSizes({ size: size, primaryPane: primaryPane, isSecondaryCollapsed: isSecondaryCollapsed }));
    }, [size, primaryPane, isSecondaryCollapsed]);
    function handleChange(newSizes) {
        setSizes(newSizes);
        currentSizes.current = newSizes;
    }
    function handleDragEnd() {
        onDragFinished === null || onDragFinished === void 0 ? void 0 : onDragFinished(currentSizes.current[0]);
    }
    function handleSecondaryClick() {
        onSecondaryToggle === null || onSecondaryToggle === void 0 ? void 0 : onSecondaryToggle(!isSecondaryCollapsed);
    }
    function renderPane(pane) {
        var isSecondaryPane = primaryPane !== pane;
        return (react_1.default.createElement(SplitViewPane_1.SplitViewPane, __assign({}, (isSecondaryPane && !isSecondaryCollapsed
            ? { minSize: minSize, maxSize: maxSize }
            : {})), isSecondaryPane && isSecondaryCollapsed ? (react_1.default.createElement("div", { className: (0, classnames_1.default)(styles_module_css_json_2.default.VerticalSplitPane__expand, styles_module_css_json_2.default["VerticalSplitPane__expand--".concat(pane)]), onClick: handleSecondaryClick })) : (children[pane === 'left' ? 0 : 1])));
    }
    if (mode === 'overlay' && !isSecondaryCollapsed && SashActionIcon) {
        var primaryPaneChild = children[primaryPane === 'left' ? 0 : 1];
        var secondaryPaneChild = children[primaryPane === 'left' ? 1 : 0];
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement("div", { className: styles_module_css_json_2.default.VerticalSplitPaneOverlay, onClick: handleSecondaryClick },
                react_1.default.createElement("div", { className: (0, classnames_1.default)(styles_module_css_json_2.default.VerticalSplitPaneOverlay__secondary, styles_module_css_json_2.default["VerticalSplitPaneOverlay__secondary--".concat(primaryPane === 'left' ? 'right' : 'left')]), style: {
                        width: size,
                        maxWidth: maxSize,
                        minWidth: minSize,
                    }, onClick: function (e) {
                        e.stopPropagation();
                    } },
                    secondaryPaneChild,
                    react_1.default.createElement("div", { className: styles_module_css_json_2.default.VerticalSplitPaneOverlay__sash },
                        react_1.default.createElement("div", { className: styles_module_css_json_1.default.SplitViewSash__content, onClick: handleSecondaryClick },
                            react_1.default.createElement("div", { className: styles_module_css_json_1.default.SplitViewSash__content__button },
                                react_1.default.createElement(SashActionIcon, null)))))),
            react_1.default.createElement("div", { className: (0, classnames_1.default)(styles_module_css_json_2.default.VerticalSplitPaneOverlay__primary, styles_module_css_json_2.default["VerticalSplitPaneOverlay__primary--".concat(primaryPane)]) }, primaryPaneChild)));
    }
    return (react_1.default.createElement(SplitView_1.SplitView, { allowResize: !isSecondaryCollapsed && allowResize, sizes: sizes, onChange: handleChange, onDragEnd: handleDragEnd, sashAction: SashActionIcon && {
            icon: react_1.default.createElement(SashActionIcon, null),
            onClick: handleSecondaryClick,
        } },
        renderPane('left'),
        renderPane('right')));
}
exports.VerticalSplit = VerticalSplit;
//# sourceMappingURL=index.js.map