import React from 'react';
import type { CSSProperties, MouseEventHandler, ReactNode } from 'react';
export declare type ButtonProps = {
    children?: ReactNode;
    type?: React.ButtonHTMLAttributes<HTMLButtonElement>['type'];
    className?: string;
    disabled?: boolean;
    onClick?: MouseEventHandler;
    buttonType?: 'primary' | 'muted' | 'negative';
    buttonSize?: 'xxs' | 'xs' | 's' | 'm' | 'l' | 'xl';
    leftIcon?: ReactNode;
    rightIcon?: ReactNode;
    fullWidth?: boolean;
    style?: CSSProperties;
};
/**
 * @example Button types
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <div style={{ marginBottom: 'var(--spacing-m)' }}>
 *     <Button buttonType="muted">Submit</Button>{' '}
 *     <Button buttonType="primary">Submit</Button>{' '}
 *     <Button buttonType="negative">Submit</Button>
 *   </div>
 *   <div>
 *     <Button buttonType="muted" disabled>
 *       Submit
 *     </Button>{' '}
 *     <Button buttonType="primary" disabled>
 *       Submit
 *     </Button>{' '}
 *     <Button buttonType="negative" disabled>
 *       Submit
 *     </Button>
 *   </div>
 * </Canvas>;
 * ```
 *
 * @example Full-width
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <Button fullWidth>Submit</Button>
 * </Canvas>;
 * ```
 *
 * @example Sizing
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <Button buttonSize="xxs">Submit</Button>{' '}
 *   <Button buttonSize="xs">Submit</Button>{' '}
 *   <Button buttonSize="s">Submit</Button>{' '}
 *   <Button buttonSize="m">Submit</Button>{' '}
 *   <Button buttonSize="l">Submit</Button>{' '}
 *   <Button buttonSize="xl">Submit</Button>{' '}
 * </Canvas>;
 * ```
 *
 * @example Icons
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <div style={{ marginBottom: 'var(--spacing-m)' }}>
 *     <Button leftIcon={<PlusIcon />}>Submit</Button>
 *   </div>
 *   <div style={{ marginBottom: 'var(--spacing-m)' }}>
 *     <Button rightIcon={<ChevronDownIcon />}>Options</Button>
 *   </div>
 *   <div>
 *     <Button leftIcon={<PlusIcon />} />
 *   </div>
 * </Canvas>;
 * ```
 */
export declare function Button({ children, className, disabled, buttonType, buttonSize, fullWidth, onClick, style, leftIcon, rightIcon, type, }: ButtonProps): JSX.Element;
export declare type ButtonLinkProps = {
    children?: ReactNode;
    href: string;
    target?: React.AnchorHTMLAttributes<HTMLAnchorElement>['target'];
    className?: string;
    onClick?: MouseEventHandler;
    buttonType?: 'primary' | 'muted' | 'negative';
    buttonSize?: 'xxs' | 'xs' | 's' | 'm' | 'l' | 'xl';
    fullWidth?: boolean;
    style?: CSSProperties;
    leftIcon?: ReactNode;
    rightIcon?: ReactNode;
};
export declare function ButtonLink({ children, href, target, className, buttonType, buttonSize, onClick, fullWidth, leftIcon, rightIcon, style, }: ButtonLinkProps): JSX.Element;
