import { type CSSProperties, type ReactNode } from 'react';
declare type SectionProps = {
    title: ReactNode;
    children?: ReactNode;
    highlighted?: boolean;
    collapsible?: {
        isOpen: boolean;
        onToggle: () => void;
    };
    headerClassName?: string;
    titleClassName?: string;
    headerStyle?: CSSProperties;
    titleStyle?: CSSProperties;
};
/**
 * @example Basic usage
 *
 * ```jsx
 * <Canvas ctx={ctx}>
 *   <Section title="Section title">
 *     Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
 *     eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim
 *     ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut
 *     aliquip ex ea commodo consequat.
 *   </Section>
 * </Canvas>;
 * ```
 *
 * @example Highlighted
 *
 * ```jsx
 * <Canvas ctx={ctx}>
 *   <Section title="Section title" highlighted>
 *     Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
 *     eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim
 *     ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut
 *     aliquip ex ea commodo consequat.
 *   </Section>
 * </Canvas>;
 * ```
 *
 * @example Collapsible
 *
 * ```jsx
 * <Canvas ctx={ctx}>
 *   <StateManager initial={true}>
 *     {(isOpen, setOpen) => (
 *       <Section
 *         title="Section title"
 *         collapsible={{ isOpen, onToggle: () => setOpen((v) => !v) }}
 *       >
 *         Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
 *         eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut
 *         enim ad minim veniam, quis nostrud exercitation ullamco laboris
 *         nisi ut aliquip ex ea commodo consequat.
 *       </Section>
 *     )}
 *   </StateManager>
 * </Canvas>;
 * ```
 */
export declare function Section({ title, children, highlighted, collapsible, headerClassName, titleClassName, headerStyle, titleStyle, }: SectionProps): JSX.Element;
export {};
