import cn from 'classnames';
import React from 'react';
import s from './styles.module.css.json';
/**
 * @example Basic usage
 *
 * ```jsx
 * <Canvas ctx={ctx}>
 *   <Section title="Section title">
 *     Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
 *     eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim
 *     ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut
 *     aliquip ex ea commodo consequat.
 *   </Section>
 * </Canvas>;
 * ```
 *
 * @example Highlighted
 *
 * ```jsx
 * <Canvas ctx={ctx}>
 *   <Section title="Section title" highlighted>
 *     Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
 *     eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim
 *     ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut
 *     aliquip ex ea commodo consequat.
 *   </Section>
 * </Canvas>;
 * ```
 *
 * @example Collapsible
 *
 * ```jsx
 * <Canvas ctx={ctx}>
 *   <StateManager initial={true}>
 *     {(isOpen, setOpen) => (
 *       <Section
 *         title="Section title"
 *         collapsible={{ isOpen, onToggle: () => setOpen((v) => !v) }}
 *       >
 *         Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
 *         eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut
 *         enim ad minim veniam, quis nostrud exercitation ullamco laboris
 *         nisi ut aliquip ex ea commodo consequat.
 *       </Section>
 *     )}
 *   </StateManager>
 * </Canvas>;
 * ```
 */
export function Section(_a) {
    var _b, _c;
    var title = _a.title, children = _a.children, highlighted = _a.highlighted, collapsible = _a.collapsible, headerClassName = _a.headerClassName, titleClassName = _a.titleClassName, headerStyle = _a.headerStyle, titleStyle = _a.titleStyle;
    return (React.createElement("div", { className: cn(s.Section, (_b = {}, _b[s['Section--highlighted']] = highlighted, _b)) },
        React.createElement("div", { className: cn(s.Section__header, headerClassName), style: headerStyle },
            React.createElement("div", { className: cn(s.Section__title, titleClassName), style: titleStyle },
                collapsible && (React.createElement("button", { type: "button", className: cn(s.Section__arrow, (_c = {},
                        _c[s['Section__arrow--is-open']] = collapsible.isOpen,
                        _c)), onClick: collapsible.onToggle })),
                React.createElement("div", { className: s.Section__title__content }, title))),
        (!collapsible || collapsible.isOpen) && children));
}
//# sourceMappingURL=index.js.map