var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import classNames from 'classnames';
import React, { useCallback, useEffect, useMemo, useRef, useState, } from 'react';
import { SplitViewPane } from './SplitViewPane';
import { SplitViewSash } from './SplitViewSash';
import s from './styles.module.css.json';
export var SplitView = function (_a) {
    var children = _a.children, propSizes = _a.sizes, _b = _a.allowResize, allowResize = _b === void 0 ? true : _b, _c = _a.split, split = _c === void 0 ? 'vertical' : _c, _d = _a.resizerSize, resizerSize = _d === void 0 ? 10 : _d, _e = _a.performanceMode, performanceMode = _e === void 0 ? false : _e, _f = _a.onChange, onChange = _f === void 0 ? function () { return null; } : _f, _g = _a.onDragStart, onDragStart = _g === void 0 ? function () { return null; } : _g, _h = _a.onDragEnd, onDragEnd = _h === void 0 ? function () { return null; } : _h, sashAction = _a.sashAction;
    var axis = useRef({ x: 0, y: 0 });
    var wrapper = useRef(null);
    var cacheSizes = useRef({ sizes: [], sashPosSizes: [] });
    var _j = useState(undefined), wrapperRect = _j[0], setWrapperRect = _j[1];
    var _k = useState(false), isDragging = _k[0], setDragging = _k[1];
    useEffect(function () {
        var resizeObserver = new ResizeObserver(function () {
            if (wrapper === null || wrapper === void 0 ? void 0 : wrapper.current) {
                setWrapperRect(wrapper.current.getBoundingClientRect());
            }
        });
        resizeObserver.observe(wrapper.current);
        return function () {
            resizeObserver.disconnect();
        };
    }, []);
    var _l = useMemo(function () { return ({
        sizeName: split === 'vertical' ? 'width' : 'height',
        splitPos: split === 'vertical' ? 'left' : 'top',
        splitAxis: split === 'vertical' ? 'x' : 'y',
    }); }, [split]), sizeName = _l.sizeName, splitPos = _l.splitPos, splitAxis = _l.splitAxis;
    var wrapSize = wrapperRect ? wrapperRect[sizeName] : 0;
    // Get limit sizes via children
    var paneLimitSizes = useMemo(function () {
        return children.map(function (childNode) {
            var limits = [0, Infinity];
            if (childNode.type === SplitViewPane) {
                var _a = childNode.props, minSize = _a.minSize, maxSize = _a.maxSize;
                limits[0] = assertSize(minSize, wrapSize, 0);
                limits[1] = assertSize(maxSize, wrapSize);
            }
            return limits;
        });
    }, [children, wrapSize]);
    var sizes = useMemo(function () {
        var count = 0;
        var curSum = 0;
        var res = children.map(function (_child, index) {
            var size = clampSize(assertSize(propSizes[index], wrapSize), paneLimitSizes[index]);
            if (size === Infinity) {
                count = count + 1;
            }
            else {
                curSum = curSum + size;
            }
            return size;
        });
        // resize or illegal size input,recalculate pane sizes
        if (curSum > wrapSize || (!count && curSum < wrapSize)) {
            var cacheNum_1 = (curSum - wrapSize) / curSum;
            return res.map(function (size) {
                return size === Infinity ? 0 : size - size * cacheNum_1;
            });
        }
        if (count > 0) {
            var average_1 = (wrapSize - curSum) / count;
            return res.map(function (size) {
                return size === Infinity ? average_1 : size;
            });
        }
        return res;
    }, [
        JSON.stringify(propSizes),
        JSON.stringify(paneLimitSizes),
        children.length,
        wrapSize,
    ]);
    var sashPosSizes = useMemo(function () { return sizes.reduce(function (a, b) { return __spreadArray(__spreadArray([], a, true), [a[a.length - 1] + b], false); }, [0]); }, [JSON.stringify(sizes)]);
    var handleMouseDown = useCallback(function (x, y) {
        var _a, _b;
        (_b = (_a = document === null || document === void 0 ? void 0 : document.body) === null || _a === void 0 ? void 0 : _a.classList) === null || _b === void 0 ? void 0 : _b.add(s['SplitView--disable-select']);
        axis.current = { x: x, y: y };
        cacheSizes.current = { sizes: sizes, sashPosSizes: sashPosSizes };
        setDragging(true);
        onDragStart();
    }, [onDragStart, sizes, sashPosSizes]);
    var handleMouseUp = useCallback(function () {
        var _a, _b;
        (_b = (_a = document === null || document === void 0 ? void 0 : document.body) === null || _a === void 0 ? void 0 : _a.classList) === null || _b === void 0 ? void 0 : _b.remove(s['SplitView--disable-select']);
        setDragging(false);
        onDragEnd();
    }, [onDragEnd]);
    var handleMouseMove = useCallback(function (x, y, i) {
        var curAxis = { x: x, y: y };
        var distanceX = curAxis[splitAxis] - axis.current[splitAxis];
        var leftBorder = -Math.min(sizes[i] - paneLimitSizes[i][0], paneLimitSizes[i + 1][1] - sizes[i + 1]);
        var rightBorder = Math.min(sizes[i + 1] - paneLimitSizes[i + 1][0], paneLimitSizes[i][1] - sizes[i]);
        if (distanceX < leftBorder) {
            distanceX = leftBorder;
        }
        if (distanceX > rightBorder) {
            distanceX = rightBorder;
        }
        var nextSizes = __spreadArray([], sizes, true);
        nextSizes[i] += distanceX;
        nextSizes[i + 1] -= distanceX;
        onChange(nextSizes);
    }, [paneLimitSizes, onChange]);
    var paneFollow = !(performanceMode && isDragging);
    var paneSizes = paneFollow ? sizes : cacheSizes.current.sizes;
    var panePoses = paneFollow ? sashPosSizes : cacheSizes.current.sashPosSizes;
    return (React.createElement("div", { className: classNames(s.SplitView, split === 'vertical' && s['SplitView--vertical'], split === 'horizontal' && s['SplitView--horizontal'], isDragging && s['SplitView--dragging']), ref: wrapper },
        children.map(function (childNode, childIndex) {
            var _a;
            var isPane = childNode.type === SplitViewPane;
            var paneProps = isPane ? childNode.props : {};
            return (React.createElement(SplitViewPane
            // biome-ignore lint/suspicious/noArrayIndexKey: <explanation>
            , { 
                // biome-ignore lint/suspicious/noArrayIndexKey: <explanation>
                key: childIndex, style: __assign(__assign({}, paneProps.style), (_a = {}, _a[sizeName] = paneSizes[childIndex], _a[splitPos] = panePoses[childIndex], _a)) }, isPane ? paneProps.children : childNode));
        }),
        sashPosSizes.slice(1, -1).map(function (posSize, index) {
            var _a;
            return (React.createElement(SplitViewSash
            // biome-ignore lint/suspicious/noArrayIndexKey: <explanation>
            , { 
                // biome-ignore lint/suspicious/noArrayIndexKey: <explanation>
                key: index, allowResize: allowResize, split: split, style: (_a = {},
                    _a[sizeName] = resizerSize,
                    _a[splitPos] = posSize - resizerSize / 2,
                    _a), onMouseDown: handleMouseDown, onMouseMove: function (x, y) { return handleMouseMove(x, y, index); }, onMouseUp: handleMouseUp, action: sashAction }));
        })));
};
/**
 * Convert size to absolute number or Infinity
 * SplitPane allows sizes in string and number, but the state sizes only support number,
 * so convert string and number to number in here
 * 'auto' -> divide the remaining space equally
 * 'xxxpx' -> xxx
 * 'xxx%' -> wrapper.size * xxx/100
 *  xxx -> xxx
 */
function assertSize(size, sum, defaultValue) {
    if (defaultValue === void 0) { defaultValue = Infinity; }
    if (typeof size === 'undefined')
        return defaultValue;
    if (typeof size === 'number')
        return size;
    if (size.endsWith('%'))
        return sum * (+size.replace('%', '') / 100);
    if (size.endsWith('px'))
        return +size.replace('px', '');
    return defaultValue;
}
function clampSize(size, minMax) {
    return Math.max(minMax[0], Math.min(minMax[1], size));
}
//# sourceMappingURL=index.js.map