var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import classNames from 'classnames';
import React, { useEffect, useRef, useState } from 'react';
import { SplitView } from '../SplitView';
import { SplitViewPane } from '../SplitView/SplitViewPane';
import sashS from '../SplitView/SplitViewSash/styles.module.css.json';
import { ChevronsLeftIcon, ChevronsRightIcon, SidebarFlipIcon } from '../icons';
import s from './styles.module.css.json';
var initialSidebarWidth = 220;
function calculateSizes(_a) {
    var size = _a.size, primaryPane = _a.primaryPane, isSecondaryCollapsed = _a.isSecondaryCollapsed;
    var realSize = isSecondaryCollapsed ? 20 : size;
    return primaryPane === 'right' ? [realSize] : ['auto', realSize];
}
/**
 * @example Resizable, left primary panel
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <div style={{ height: 500, position: 'relative' }}>
 *     <VerticalSplit primaryPane="left" size="25%" minSize={220}>
 *       <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
 *         <Toolbar>
 *           <ToolbarStack stackSize="l">
 *             <ToolbarTitle>Primary</ToolbarTitle>
 *           </ToolbarStack>
 *         </Toolbar>
 *         <div
 *           style={{
 *             flex: '1',
 *             display: 'flex',
 *             justifyContent: 'center',
 *             alignItems: 'center',
 *             height: '150px',
 *           }}
 *         >
 *           Main content
 *         </div>
 *       </div>
 *       <div style={{ display: 'flex', flexDirection: 'column', height: '100%', borderLeft: '1px solid var(--border-color)' }}>
 *         <Toolbar>
 *           <ToolbarStack stackSize="l">
 *             <ToolbarTitle>Secondary</ToolbarTitle>
 *           </ToolbarStack>
 *         </Toolbar>
 *         <div
 *           style={{
 *             flex: '1',
 *             display: 'flex',
 *             justifyContent: 'center',
 *             alignItems: 'center',
 *             height: '150px',
 *           }}
 *         >
 *           Sidebar
 *         </div>
 *       </div>
 *     </VerticalSplit>
 *   </div>
 * </Canvas>;
 * ```
 *
 * @example Resizable, right primary panel
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <div style={{ height: 500, position: 'relative' }}>
 *     <VerticalSplit primaryPane="right" size="25%" minSize={220}>
 *       <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
 *         <Toolbar>
 *           <ToolbarStack stackSize="l">
 *             <ToolbarTitle>Secondary</ToolbarTitle>
 *           </ToolbarStack>
 *         </Toolbar>
 *         <div
 *           style={{
 *             flex: '1',
 *             display: 'flex',
 *             justifyContent: 'center',
 *             alignItems: 'center',
 *             height: '150px',
 *           }}
 *         >
 *           Sidebar
 *         </div>
 *       </div>
 *       <div style={{ display: 'flex', flexDirection: 'column', height: '100%', borderLeft: '1px solid var(--border-color)' }}>
 *         <Toolbar>
 *           <ToolbarStack stackSize="l">
 *             <ToolbarTitle>Primary</ToolbarTitle>
 *           </ToolbarStack>
 *         </Toolbar>
 *         <div
 *           style={{
 *             flex: '1',
 *             display: 'flex',
 *             justifyContent: 'center',
 *             alignItems: 'center',
 *             height: '150px',
 *           }}
 *         >
 *           Main content
 *         </div>
 *       </div>
 *     </VerticalSplit>
 *   </div>
 * </Canvas>;
 * ```
 *
 * @example Collapsible
 *
 * ```js
 *   <Canvas ctx={ctx}>
 *    <div style={{ height: 500, position: 'relative' }}>
 *      <StateManager initial={true}>
 *        {(isCollapsed, setCollapsed) => (
 *          <VerticalSplit
 *            primaryPane="left"
 *            size="25%"
 *            minSize={220}
 *            isSecondaryCollapsed={isCollapsed}
 *            onSecondaryToggle={setCollapsed}
 *          >
 *            <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
 *              <Toolbar>
 *                <ToolbarStack stackSize="l">
 *                  <ToolbarTitle>Primary</ToolbarTitle>
 *                </ToolbarStack>
 *              </Toolbar>
 *              <div
 *                style={{
 *                  flex: '1',
 *                  display: 'flex',
 *                  justifyContent: 'center',
 *                  alignItems: 'center',
 *                  height: '150px',
 *                }}
 *              >
 *                Main content
 *              </div>
 *            </div>
 *            <div
 *              style={{
 *                display: 'flex',
 *                flexDirection: 'column',
 *                height: '100%',
 *                borderLeft: '1px solid var(--border-color)',
 *              }}
 *            >
 *              <Toolbar>
 *                <ToolbarStack stackSize="l">
 *                  <ToolbarTitle>Secondary</ToolbarTitle>
 *                </ToolbarStack>
 *              </Toolbar>
 *              <div
 *                style={{
 *                  flex: '1',
 *                  display: 'flex',
 *                  justifyContent: 'center',
 *                  alignItems: 'center',
 *                  height: '150px',
 *                }}
 *              >
 *                Sidebar
 *              </div>
 *            </div>
 *          </VerticalSplit>
 *        )}
 *      </StateManager>
 *    </div>
 *  </Canvas>;
 * ```
 *
 * @example Overlay mode
 *
 * ```js
 *   <Canvas ctx={ctx}>
 *    <div style={{ height: 500, position: 'relative' }}>
 *      <StateManager initial={true}>
 *        {(isCollapsed, setCollapsed) => (
 *          <VerticalSplit
 *            mode="overlay"
 *            primaryPane="left"
 *            size="25%"
 *            minSize={220}
 *            isSecondaryCollapsed={isCollapsed}
 *            onSecondaryToggle={setCollapsed}
 *          >
 *            <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
 *              <Toolbar>
 *                <ToolbarStack stackSize="l">
 *                  <ToolbarTitle>Primary</ToolbarTitle>
 *                </ToolbarStack>
 *              </Toolbar>
 *              <div
 *                style={{
 *                  flex: '1',
 *                  display: 'flex',
 *                  justifyContent: 'center',
 *                  alignItems: 'center',
 *                  height: '150px',
 *                }}
 *              >
 *                Main content
 *              </div>
 *            </div>
 *            <div
 *              style={{
 *                display: 'flex',
 *                flexDirection: 'column',
 *                height: '100%',
 *                borderLeft: '1px solid var(--border-color)',
 *              }}
 *            >
 *              <Toolbar>
 *                <ToolbarStack stackSize="l">
 *                  <ToolbarTitle>Secondary</ToolbarTitle>
 *                </ToolbarStack>
 *              </Toolbar>
 *              <div
 *                style={{
 *                  flex: '1',
 *                  display: 'flex',
 *                  justifyContent: 'center',
 *                  alignItems: 'center',
 *                  height: '150px',
 *                }}
 *              >
 *                Sidebar
 *              </div>
 *            </div>
 *          </VerticalSplit>
 *        )}
 *      </StateManager>
 *    </div>
 *  </Canvas>;
 * ```
 */
export function VerticalSplit(_a) {
    var _b = _a.mode, mode = _b === void 0 ? 'split' : _b, _c = _a.minSize, minSize = _c === void 0 ? 200 : _c, maxSize = _a.maxSize, _d = _a.size, size = _d === void 0 ? initialSidebarWidth : _d, primaryPane = _a.primaryPane, children = _a.children, _e = _a.allowResize, allowResize = _e === void 0 ? true : _e, onDragFinished = _a.onDragFinished, onSecondaryToggle = _a.onSecondaryToggle, isSecondaryCollapsed = _a.isSecondaryCollapsed;
    var _f = useState(calculateSizes({ size: size, primaryPane: primaryPane, isSecondaryCollapsed: isSecondaryCollapsed })), sizes = _f[0], setSizes = _f[1];
    var currentSizes = useRef(sizes);
    var SashActionIcon = onSecondaryToggle
        ? primaryPane === 'left'
            ? isSecondaryCollapsed
                ? SidebarFlipIcon
                : ChevronsRightIcon
            : isSecondaryCollapsed
                ? ChevronsRightIcon
                : ChevronsLeftIcon
        : undefined;
    useEffect(function () {
        setSizes(calculateSizes({ size: size, primaryPane: primaryPane, isSecondaryCollapsed: isSecondaryCollapsed }));
    }, [size, primaryPane, isSecondaryCollapsed]);
    function handleChange(newSizes) {
        setSizes(newSizes);
        currentSizes.current = newSizes;
    }
    function handleDragEnd() {
        onDragFinished === null || onDragFinished === void 0 ? void 0 : onDragFinished(currentSizes.current[0]);
    }
    function handleSecondaryClick() {
        onSecondaryToggle === null || onSecondaryToggle === void 0 ? void 0 : onSecondaryToggle(!isSecondaryCollapsed);
    }
    function renderPane(pane) {
        var isSecondaryPane = primaryPane !== pane;
        return (React.createElement(SplitViewPane, __assign({}, (isSecondaryPane && !isSecondaryCollapsed
            ? { minSize: minSize, maxSize: maxSize }
            : {})), isSecondaryPane && isSecondaryCollapsed ? (React.createElement("div", { className: classNames(s.VerticalSplitPane__expand, s["VerticalSplitPane__expand--".concat(pane)]), onClick: handleSecondaryClick })) : (children[pane === 'left' ? 0 : 1])));
    }
    if (mode === 'overlay' && !isSecondaryCollapsed && SashActionIcon) {
        var primaryPaneChild = children[primaryPane === 'left' ? 0 : 1];
        var secondaryPaneChild = children[primaryPane === 'left' ? 1 : 0];
        return (React.createElement(React.Fragment, null,
            React.createElement("div", { className: s.VerticalSplitPaneOverlay, onClick: handleSecondaryClick },
                React.createElement("div", { className: classNames(s.VerticalSplitPaneOverlay__secondary, s["VerticalSplitPaneOverlay__secondary--".concat(primaryPane === 'left' ? 'right' : 'left')]), style: {
                        width: size,
                        maxWidth: maxSize,
                        minWidth: minSize,
                    }, onClick: function (e) {
                        e.stopPropagation();
                    } },
                    secondaryPaneChild,
                    React.createElement("div", { className: s.VerticalSplitPaneOverlay__sash },
                        React.createElement("div", { className: sashS.SplitViewSash__content, onClick: handleSecondaryClick },
                            React.createElement("div", { className: sashS.SplitViewSash__content__button },
                                React.createElement(SashActionIcon, null)))))),
            React.createElement("div", { className: classNames(s.VerticalSplitPaneOverlay__primary, s["VerticalSplitPaneOverlay__primary--".concat(primaryPane)]) }, primaryPaneChild)));
    }
    return (React.createElement(SplitView, { allowResize: !isSecondaryCollapsed && allowResize, sizes: sizes, onChange: handleChange, onDragEnd: handleDragEnd, sashAction: SashActionIcon && {
            icon: React.createElement(SashActionIcon, null),
            onClick: handleSecondaryClick,
        } },
        renderPane('left'),
        renderPane('right')));
}
//# sourceMappingURL=index.js.map