import React from 'react';
var list = {};
export function useMediaQuery(media) {
    var mediaQueryList = React.useMemo(function () {
        // We have an existing mediaQueryList for media.
        if (list[media]) {
            return list[media].mql;
        }
        if (typeof window !== 'undefined') {
            return matchMedia(media);
        }
        // Server: use a fallback.
        return { matches: true, media: media };
    }, [list, media]);
    // Since the mediaQueryList is shared we use state to trigger re-renders.
    // This is done with update({}) (a new object instance will force a re-rendering).
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    var _a = React.useState({}), _ = _a[0], update = _a[1];
    React.useLayoutEffect(function () {
        if (list[media]) {
            list[media].notifiers.push(update);
        }
        else {
            list[media] = {
                mql: mediaQueryList,
                notifiers: [update],
                listener: function (mql) {
                    var match = list[mql.media];
                    if (match) {
                        for (var _i = 0, _a = match.notifiers; _i < _a.length; _i++) {
                            var updateFn = _a[_i];
                            updateFn({});
                        }
                    }
                },
            };
            list[media].mql.addEventListener('change', list[media].listener);
        }
        return function () {
            var notifierIndex = list[media].notifiers.indexOf(update);
            if (notifierIndex > -1) {
                // Remove `update`.
                list[media].notifiers.splice(notifierIndex, 1);
            }
            if (list[media].notifiers.length === 0) {
                list[media].mql.removeEventListener('change', list[media].listener);
                delete list[media];
            }
        };
    }, [list, media, mediaQueryList]);
    return mediaQueryList;
}
export function MediaQuery(_a) {
    var media = _a.media, children = _a.children;
    var mql = useMediaQuery(media);
    return typeof children === 'function' ? children(mql) : null;
}
var DOM_LAYOUT_HANDLER_NAME = '__reactLayoutHandler';
var supportsBorderBox = (function () {
    if (typeof document === 'undefined') {
        return false;
    }
    var e = document.body.appendChild(document.createElement('div'));
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    var observer = new ResizeObserver(function () { });
    try {
        observer.observe(e, { box: 'border-box' });
        observer.unobserve(e);
        return true;
    }
    catch (error) {
        return false;
    }
    finally {
        document.body.removeChild(e);
    }
})();
var resizeObserver = null;
function getResizeObserver() {
    if (resizeObserver) {
        return resizeObserver;
    }
    if (typeof ResizeObserver === 'undefined') {
        return;
    }
    resizeObserver = new ResizeObserver(function (entries) {
        var _loop_1 = function (entry) {
            var node = entry.target;
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            var onLayout = node[DOM_LAYOUT_HANDLER_NAME];
            if (typeof onLayout !== 'function') {
                return { value: void 0 };
            }
            if (supportsBorderBox && entry.borderBoxSize) {
                var boxSize_1 = entry.borderBoxSize[0] || entry.borderBoxSize;
                onLayout(function (prevRect) {
                    if (prevRect.width === boxSize_1.inlineSize &&
                        prevRect.height === boxSize_1.blockSize) {
                        return prevRect;
                    }
                    return new DOMRect(0, 0, boxSize_1.inlineSize, boxSize_1.blockSize);
                });
                return { value: void 0 };
            }
            var elRect = entry.target.getBoundingClientRect();
            onLayout(function (prevRect) {
                if (prevRect.width === elRect.width &&
                    prevRect.height === elRect.height) {
                    return prevRect;
                }
                return new DOMRect(0, 0, elRect.width, elRect.height);
            });
        };
        for (var _i = 0, entries_1 = entries; _i < entries_1.length; _i++) {
            var entry = entries_1[_i];
            var state_1 = _loop_1(entry);
            if (typeof state_1 === "object")
                return state_1.value;
        }
    });
    return resizeObserver;
}
export function useElementLayout(ref) {
    var observer = getResizeObserver();
    var _a = React.useState(new DOMRect()), rect = _a[0], setRect = _a[1];
    React.useLayoutEffect(function () {
        var node = ref.current;
        if (node) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            node[DOM_LAYOUT_HANDLER_NAME] = setRect;
        }
        if (node && observer) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            if (typeof node[DOM_LAYOUT_HANDLER_NAME] === 'function') {
                observer.observe(node, supportsBorderBox ? { box: 'border-box' } : undefined);
            }
            else {
                observer.unobserve(node);
            }
        }
        return function () {
            if (node != null && observer != null) {
                observer.unobserve(node);
            }
        };
    }, [ref, observer]);
    return rect;
}
//# sourceMappingURL=index.js.map