import { type ReactNode } from 'react';
export declare type SidebarPanelProps = {
    title?: ReactNode;
    startOpen?: boolean;
    children: ReactNode;
    noPadding?: boolean;
};
/**
 * @example Basic example
 *
 * ```js
 * <Canvas ctx={ctx}>
 *   <div style={{ display: 'flex' }}>
 *     <div
 *       style={{
 *         width: '300px',
 *         borderRight: '1px solid var(--border-color)',
 *       }}
 *     >
 *       <SidebarPanel title="Default">Content</SidebarPanel>
 *       <SidebarPanel title="Start open" startOpen>
 *         Content
 *       </SidebarPanel>
 *       <SidebarPanel title="Content with no padding" noPadding>
 *         Content
 *       </SidebarPanel>
 *     </div>
 *     <div
 *       style={{
 *         flex: '1',
 *         display: 'flex',
 *         justifyContent: 'center',
 *         alignItems: 'center',
 *         background: 'var(--light-bg-color)',
 *       }}
 *     >
 *       Main content
 *     </div>
 *   </div>
 * </Canvas>;
 * ```
 */
export declare function SidebarPanel({ startOpen, title, children, noPadding, }: SidebarPanelProps): JSX.Element;
